import { IAutoScalingGroup } from 'aws-cdk-lib/aws-autoscaling';
import { CronOptions } from 'aws-cdk-lib/aws-events';
import { Construct } from 'constructs';
/**
 * Props for the NightNight construct.
 */
export interface NightyNightForAsgProps {
    /**
     * An option CronOptions to specify the time of day to scale.
     *
     * @default {
        day: '*',
        hour: '4',
        minute: '0'
      }
     */
    readonly schedule?: CronOptions;
    /**
     * the AutoScalingGroup you'd like to change the instance count on.
     */
    readonly autoScalingGroup: IAutoScalingGroup;
    /**
     * Desired capacity
     */
    readonly desiredCapacity: number;
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule)
 * that will set the given ASG's desired capacity.
 *
 * Typically used when you've got and ASG that you can scale during set hours.
 */
export declare class NightyNightForAsg extends Construct {
    constructor(scope: Construct, id: string, props: NightyNightForAsgProps);
}
