import { CronOptions } from 'aws-cdk-lib/aws-events';
import { Construct } from 'constructs';
/**
 * Props for the NightNight construct.
 */
export interface NightyNightForEc2Props {
    /**
     * An option CronOptions to specify the time of day to stop the instance.
     *
     * @default {
        day: '*',
        hour: '4',
        minute: '0'
      }
     */
    readonly schedule?: CronOptions;
    /**
     * the instanceId of the EC2 instance you'd like stopped. Must provide this if tags is not provided.
     */
    readonly instanceId?: string;
    /**
     * Filters to match to find an EC2 instance. Must provide this if instanceId is not provided. If instanceId is provided this
     * is ignored.
     */
    readonly filters?: any[];
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule)
 * that will stop the given ec2 instance at the specified time.
 *
 * Typically used when you've got ec2 instances that you only need during business hours
 * and want to reduce the costs of.
 */
export declare class NightyNightForEc2 extends Construct {
    constructor(scope: Construct, id: string, props: NightyNightForEc2Props);
}
export interface NightyNightProps extends NightyNightForEc2Props {
}
/**
 * This class is deprecated, please use NightyNightForEc2
 *
 * @deprecated in favor of NightyNightForEc2
 */
export declare class NightyNight extends NightyNightForEc2 {
    constructor(scope: Construct, id: string, props: NightyNightProps);
}
export interface WakeyWakeyForEc2Props {
    /**
     * An option CronOptions to specify the time of day to start the instance.
     *
     * @default {
        day: '*',
        hour: '12',
        minute: '0'
      }
     */
    readonly schedule?: CronOptions;
    /**
     * the instanceId of the EC2 instance you'd like started. If instanceId is provided the filters is ignored.
     */
    readonly instanceId?: string;
    /**
     * Filters to match to find an EC2 instance. Must provide this if instanceId is not provided. If instanceId is provided this
     * is ignored.
     *
     * @example [{
     Name: 'STRING_VALUE',
     Values: [
     'STRING_VALUE',
     ]
     }]
     */
    readonly filters?: any[];
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule)
 * that will start the given ec2 instance at the specified time.
 *
 * Typically used when you've got ec2 instances that you only need during business hours
 * and want to reduce the costs of. Use in conjunction with the Nightynight construct at
 * @matthewbonig/nightynight
 */
export declare class WakeyWakeyForEc2 extends Construct {
    constructor(scope: Construct, id: string, props: WakeyWakeyForEc2Props);
}
