import { ICluster } from 'aws-cdk-lib/aws-ecs';
import { CronOptions } from 'aws-cdk-lib/aws-events';
import { Construct } from 'constructs';
/**
 * Props for the NightNight construct.
 */
export interface NightyNightForEcsProps {
    /**
     * An option CronOptions to specify the time of day to scale.
     *
     * @default {
        day: '*',
        hour: '4',
        minute: '0'
      }
     */
    readonly schedule?: CronOptions;
    /**
     * The ECS Cluster where the service resides.
     *
     * @default 'default'
     */
    readonly cluster?: ICluster;
    /**
     * The service name to update
     */
    readonly serviceName: string;
    /**
     * Desired capacity
     */
    readonly desiredCapacity: number;
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule)
 * that will set the given ECS Service's desired capacity.
 *
 * Typically, used when you've got an ECS Service that you can scale during set hours.
 */
export declare class NightyNightForEcs extends Construct {
    constructor(scope: Construct, id: string, props: NightyNightForEcsProps);
}
