import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement } from '../../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [launchwizard](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslaunchwizard.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Launchwizard extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to create an additional node
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toCreateAdditionalNode(): this;
    /**
     * Grants permission to create a deployment
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toCreateDeployment(): this;
    /**
     * Grants permission to create an application settings set
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toCreateSettingsSet(): this;
    /**
     * Grants permission to delete an additional node
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDeleteAdditionalNode(): this;
    /**
     * Grants permission to delete an application
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDeleteApp(): this;
    /**
     * Grants permission to delete a deployment
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDeleteDeployment(): this;
    /**
     * Grants permission to delete a settings set
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDeleteSettingsSet(): this;
    /**
     * Grants permission to describe an additional node
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDescribeAdditionalNode(): this;
    /**
     * Grants permission to describe provisioning applications
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDescribeProvisionedApp(): this;
    /**
     * Grants permission to describe provisioning events
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDescribeProvisioningEvents(): this;
    /**
     * Grants permission to describe an application settings set
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toDescribeSettingsSet(): this;
    /**
     * Grants permission to get a deployment
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetDeployment(): this;
    /**
     * Grants permission to get infrastructure suggestion
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetInfrastructureSuggestion(): this;
    /**
     * Grants permission to get customer's ip address
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetIpAddress(): this;
    /**
     * Grants permission to get resource cost estimate
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetResourceCostEstimate(): this;
    /**
     * Grants permission to get recommendation for a resource
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetResourceRecommendation(): this;
    /**
     * Grants permission to get a settings set
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetSettingsSet(): this;
    /**
     * Grants permission to get a workload
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetWorkload(): this;
    /**
     * Grants permission to get a workload's asset
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetWorkloadAsset(): this;
    /**
     * Grants permission to get workload assets
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toGetWorkloadAssets(): this;
    /**
     * Grants permission to list additional nodes
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListAdditionalNodes(): this;
    /**
     * Grants permission to list the allowed resources
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListAllowedResources(): this;
    /**
     * Grants permission to list the events that occured during a deployment
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListDeploymentEvents(): this;
    /**
     * Grants permission to list deployments
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListDeployments(): this;
    /**
     * Grants permission to list provisioning applications
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListProvisionedApps(): this;
    /**
     * Grants permission to list the cost estimates of resources
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListResourceCostEstimates(): this;
    /**
     * Grants permission to list settings sets
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListSettingsSets(): this;
    /**
     * Grants permission to list deployment options of a given workload
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListWorkloadDeploymentOptions(): this;
    /**
     * Grants permission to list the deployment patterns of a workload
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListWorkloadDeploymentPatterns(): this;
    /**
     * Grants permission to list workloads
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toListWorkloads(): this;
    /**
     * Grants permission to create a settings set
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toPutSettingsSet(): this;
    /**
     * Grants permission to start a provisioning
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toStartProvisioning(): this;
    /**
     * Grants permission to update an application settings set
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/launchwizard/
     */
    toUpdateSettingsSet(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Statement provider for service [launchwizard](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslaunchwizard.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
