import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement } from '../../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [qapps](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonqbusinessqapps.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Qapps extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to associate Q App with a user in Q Business application
     *
     * Access Level: Write
     */
    toAssociateQAppWithUser(): this;
    /**
     * Grants permission to copy Q App in Q Business application
     *
     * Access Level: Write
     */
    toCopyQApp(): this;
    /**
     * Grants permission to create a library item in Q Business application
     *
     * Access Level: Write
     */
    toCreateLibraryItem(): this;
    /**
     * Grants permission to create a library item review in Q Business application
     *
     * Access Level: Write
     */
    toCreateLibraryItemReview(): this;
    /**
     * Grants permission to create Q App in Q Business application
     *
     * Access Level: Write
     */
    toCreateQApp(): this;
    /**
     * Grants permission to subscribe to a Q App event bus topic in Q Business application
     *
     * Access Level: Write
     */
    toCreateSubscriptionToken(): this;
    /**
     * Grants permission to delete a library item in Q Business application
     *
     * Access Level: Write
     */
    toDeleteLibraryItem(): this;
    /**
     * Grants permission to delete Q App in Q Business application
     *
     * Access Level: Write
     */
    toDeleteQApp(): this;
    /**
     * Grants permission to disassociate Q App with a user in Q Business application
     *
     * Access Level: Write
     */
    toDisassociateQAppFromUser(): this;
    /**
     * Grants permission to get a library item in Q Business application
     *
     * Access Level: Read
     */
    toGetLibraryItem(): this;
    /**
     * Grants permission to get Q App in Q Business application
     *
     * Access Level: Read
     */
    toGetQApp(): this;
    /**
     * Grants permission to import a document to Q App in Q Business application
     *
     * Access Level: Write
     */
    toImportDocumentToQApp(): this;
    /**
     * Grants permission to import a document to Q App session in Q Business application
     *
     * Access Level: Write
     */
    toImportDocumentToQAppSession(): this;
    /**
     * Grants permission to list library items in Q Business application
     *
     * Access Level: List
     */
    toListLibraryItems(): this;
    /**
     * Grants permission to list Q Apps in Q Business application
     *
     * Access Level: List
     */
    toListQApps(): this;
    /**
     * Grants permission to predict problem statement from conversation log in Q Business application
     *
     * Access Level: Write
     */
    toPredictProblemStatementFromConversation(): this;
    /**
     * Grants permission to predict Q App metadata from problem statement in Q Business application
     *
     * Access Level: Write
     */
    toPredictQAppFromProblemStatement(): this;
    /**
     * Grants permission to start Q App session in Q Business application
     *
     * Access Level: Write
     */
    toStartQAppSession(): this;
    /**
     * Grants permission to stop Q App session in Q Business application
     *
     * Access Level: Write
     */
    toStopQAppSession(): this;
    /**
     * Grants permission to update a library item in Q Business application
     *
     * Access Level: Write
     */
    toUpdateLibraryItem(): this;
    /**
     * Grants permission to update Q App in Q Business application
     *
     * Access Level: Write
     */
    toUpdateQApp(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Adds a resource of type application to the statement
     *
     * https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/create-app.html
     *
     * @param applicationId - Identifier for the applicationId.
     * @param account - Account of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's account.
     * @param region - Region of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's region.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`, unless using the CDK, where the default is the current Stack's partition.
     */
    onApplication(applicationId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Statement provider for service [qapps](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonqbusinessqapps.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
